==> haskell-project-template-0.2.0.1-149-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-project-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: project-template
version: 0.2.0.1
id: project-template-0.2.0.1-39PNeVsL0a0JyDMiOtGpLy
key: project-template-0.2.0.1-39PNeVsL0a0JyDMiOtGpLy
license: BSD-3-Clause
maintainer: michael@fpcomplete.com
author: Michael Snoyman
homepage: https://github.com/fpco/haskell-ide
synopsis: Specify Haskell project templates and generate files
description:
    See initial blog post for explanation: <http://www.yesodweb.com/blog/2012/09/project-templates>
category: Development
abi: 2263d9626ecd50aa5637a1f84c1dec4a
exposed: True
exposed-modules:
    Text.ProjectTemplate
import-dirs: /usr/lib/ghc-8.6.5/site-local/project-template-0.2.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/project-template-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/project-template-0.2.0.1
hs-libraries: HSproject-template-0.2.0.1-39PNeVsL0a0JyDMiOtGpLy
depends:
    base-4.12.0.0 base64-bytestring-1.0.0.2-4mGTJNwsUu7LJDOWBfkS70
    bytestring-0.10.8.2 conduit-1.3.1.1-JSdi7R8L6wUIGZiBi8qKpO
    conduit-extra-1.3.2-D50RCH6hLiF4M9x0U29P7E containers-0.6.0.1
    directory-1.3.3.0 filepath-1.4.2.1 mtl-2.2.2
    resourcet-1.2.2-BD7KiCA7p3Q4m6RD0qps5k text-1.2.3.1
    transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-project-template/html/project-template.haddock
haddock-html: /usr/share/doc/haskell-project-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-project-template-0.2.0.1-150-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-project-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: project-template
version: 0.2.0.1
id: project-template-0.2.0.1-BgFCFzmWhgpEBbDtFerYWg
key: project-template-0.2.0.1-BgFCFzmWhgpEBbDtFerYWg
license: BSD-3-Clause
maintainer: michael@fpcomplete.com
author: Michael Snoyman
homepage: https://github.com/fpco/haskell-ide
synopsis: Specify Haskell project templates and generate files
description:
    See initial blog post for explanation: <http://www.yesodweb.com/blog/2012/09/project-templates>
category: Development
abi: aaadb35eb4190fcc5a2a25c422587ce6
exposed: True
exposed-modules:
    Text.ProjectTemplate
import-dirs: /usr/lib/ghc-8.6.5/site-local/project-template-0.2.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/project-template-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/project-template-0.2.0.1
hs-libraries: HSproject-template-0.2.0.1-BgFCFzmWhgpEBbDtFerYWg
depends:
    base-4.12.0.0 base64-bytestring-1.0.0.2-4mGTJNwsUu7LJDOWBfkS70
    bytestring-0.10.8.2 conduit-1.3.1.1-JSdi7R8L6wUIGZiBi8qKpO
    conduit-extra-1.3.2-7VXB1JXOEmvJAFDjZlGCzm containers-0.6.0.1
    directory-1.3.3.0 filepath-1.4.2.1 mtl-2.2.2
    resourcet-1.2.2-BD7KiCA7p3Q4m6RD0qps5k text-1.2.3.1
    transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-project-template/html/project-template.haddock
haddock-html: /usr/share/doc/haskell-project-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
